function Video(id) {
    var self = this
    self.id = id
    self.playedTime = 0
    self.startPlayTimeStamp = 0
    self.jwPlayer = undefined

    self.getJwPlayer = function() {
        if (
            self.jwPlayer === undefined
            && typeof jwplayer !== 'undefined'
            && typeof jwplayer(id).getPlaylistItem === 'function'
        ) {
            self.jwPlayer = jwplayer(id)
        }

        return self.jwPlayer
    }

    self.onStop = function() {
        self.playedTime = self.getPlayedTime()
        self.startPlayTimeStamp = 0
    }

    self.onPlay = function() {
        self.onStop()
        self.startPlayTimeStamp = Math.round((new Date()).getTime() / 1000);
    }

    self.getPlayedTime = function() {
        var currentTimeStamp = Math.round((new Date()).getTime() / 1000);
        var playedTime = self.playedTime
        if (self.startPlayTimeStamp > 0) {
            playedTime += currentTimeStamp - self.startPlayTimeStamp
        }
        return playedTime
    }

    self.readyJwPlayer = function() {
        if (self.getJwPlayer() !== undefined) {
            self.getJwPlayer().onPlay(self.onPlay);
            self.getJwPlayer().onPause(self.onStop());
            self.getJwPlayer().onComplete(self.onStop());

            setInterval(function () {self.checkJwPlayer()}, 1000);
        }
    }

    self.checkJwPlayer = function(id) {
        if (jwplayer(id).getState() === 'PLAYING') {
            var playedTime = self.getPlayedTime()
            _paq.push(['trackEvent', 'Video', 'Progress' + jwplayer().getPlaylistItem().file, playedTime]);
        } else {
            self.onStop()
        }
    }
}

function Tracker() {
    var self = this
    self.videos = undefined
    self.shopname = ''
    self.url = ''

    self.initVideos = function () {
        if (self.videos === undefined) {
            var elements = document.querySelectorAll(".video-holder>div:first-of-type");
            self.videos = Array.prototype.reduce.call(elements, function(map, obj) {
                map[obj.id] = {
                    playedTime: 0,
                    startPlay: 0
                };
                map[obj.id] = new Video(obj.id)
                map[obj.id].readyJwPlayer()
                return map;
            }, {});
        }

        return self.videos
    }


}

function ready() {
    var result = getJsonFromUrl(window.location.search)

    _paq = window._paq || [];
    if (result.shopname !== undefined) {
        _paq.push(['setUserId', result.shopname]);
    }
    _paq.push(['trackPageView']);
    _paq.push(['enableLinkTracking']);
    (function() {
        var u="//objects.icecat.biz/statistics/";
        _paq.push(['setTrackerUrl', u+'matomo.php']);
        _paq.push(['setSiteId', '2']);
        var d=document, g=d.createElement('script'), s=d.getElementsByTagName('script')[0];
        g.type='text/javascript'; g.async=true; g.defer=true; g.src=u+'matomo.js'; s.parentNode.insertBefore(g,s);
    })();
    _paq.push(['trackVisibleContentImpressions', true, 750]);

    if (result.product_id !== undefined) {
        _paq.push(['setCustomVariable', 2, 'product_id', result.product_id, 'page' ])
    }
    var tracker = new Tracker()
    tracker.initVideos()
}

function getJsonFromUrl(url) {
    if(!url) url = location.search;
    var query = url.substr(1);
    var result = {};
    query.split("&").forEach(function(part) {
        var item = part.split("=");
        result[item[0]] = decodeURIComponent(item[1]);
    });
    return result;
}

window.onload = function () { ready() }
